@@ -1,9 +1,9 @@
 package Sah::Schemas::Git;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-03-27'; # DATE
+our $DATE = '2021-07-20'; # DATE
 our $DIST = 'Sah-Schemas-Git'; # DIST
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 1;
 # ABSTRACT: Sah schemas related to git
@@ -20,10 +20,26 @@ Sah::Schemas::Git - Sah schemas related to git
 
 =head1 VERSION
 
-This document describes version 0.003 of Sah::Schemas::Git (from Perl distribution Sah-Schemas-Git), released on 2020-03-27.
+This document describes version 0.004 of Sah::Schemas::Git (from Perl distribution Sah-Schemas-Git), released on 2021-07-20.
 
 =head1 SYNOPSIS
 
+=head1 CONTRIBUTOR
+
+=for stopwords perlancar (on netbook-dell-xps13)
+
+perlancar (on netbook-dell-xps13) <perlancar@gmail.com>
+
+=head1 SAH SCHEMAS
+
+=over
+
+=item * L<git::refname|Sah::Schema::git::refname>
+
+git reference name.
+
+=back
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-Git>.
@@ -52,7 +68,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
